import logging
from logging.handlers import TimedRotatingFileHandler
import sys
log_format = logging.Formatter('%(asctime)s %(levelname)s:%(message)s')
log_file = 'output.log'


class CustomFormatter(logging.Formatter):

    grey = "\x1b[38;20m"
    yellow = "\x1b[33;20m"
    red = "\x1b[31;20m"
    bold_red = "\x1b[31;1m"
    reset = "\x1b[0m"
    format = "%(asctime)s %(levelname)s - %(message)s"

    FORMATS = {
        logging.DEBUG: grey + format + reset,
        logging.INFO: grey + format + reset,
        logging.WARNING: yellow + format + reset,
        logging.ERROR: red + format + reset,
        logging.CRITICAL: bold_red + format + reset
    }

    def format(self, record):
        log_fmt = self.FORMATS.get(record.levelno)
        formatter = logging.Formatter(log_fmt)
        return formatter.format(record)


class MyLog:

    def __init__(self):
        self.logger = logging.getLogger("main")
        self.logger.setLevel(logging.DEBUG)
        # Console logging
        console_handler = logging.StreamHandler(sys.stdout)
        console_handler.setFormatter(log_format)

        console = console_handler
        console.setFormatter(CustomFormatter())
        self.logger.addHandler(console)

        file_handler = TimedRotatingFileHandler(log_file, when='midnight')
        file_handler.setFormatter(log_format)
        self.logger.addHandler(file_handler)
        self.logger.propagate = False
